package mschmidt.komo.datatools;
/*
 * Instances of this object class manages the database password for the current
 * session, allowing it to be set or changed and making it available throughout
 * the program.
 * 
 * @author Mike and Janet
 * 
 */

import mschmidt.komo.KomoPlugin;
import mschmidt.komo.preferences.PreferenceConstants;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.PlatformUI;

public class PasswordManager {

	// Initialize password related variables.
	private IPreferenceStore store = KomoPlugin.getDefault()
			.getPreferenceStore();

	private String dbPassword = new String();

	private String initPW = new String();

	/**
	 * Constructor to create an instance of the PasswordManager object 
	 * and initialize its variables.
	 */
	public PasswordManager() {

		// Get the default password from the PreferenceStore.
		initPW = store.getDefaultString(PreferenceConstants.DB_PASSWORD);

		// If the user has stored a password, get it.
		if (!store.isDefault(PreferenceConstants.DB_PASSWORD)) {
			dbPassword = store.getString(PreferenceConstants.DB_PASSWORD);
		}
	}

	/**
	 * This method is called when database access is attempted. If the password
	 * isn't stored, obtain it via user input with the newPassword method.
	 * Store the password for this session only.
	 * 
	 * @return passwordOK true if a password is available, false if not.
	 */
	public final boolean checkPassword() {
		boolean passwordOK = true;
		if (dbPassword.length() == 0 || dbPassword == null 
				|| dbPassword.equals(initPW)) {
			dbPassword = "";
			String currPW = store.getString(PreferenceConstants.DB_PASSWORD);
			if (currPW.equals(initPW)) {
				newPassword("");
				if (dbPassword.length() == 0 ||dbPassword == null 
						|| dbPassword.equals(initPW)) {
					passwordOK = false;
				}

			} else {
				dbPassword = currPW;
			}
		}
		return passwordOK;
	}

	/**
	 * Allow user to change the password by opening a dialog window using
	 * newPassword method.
	 */
	public final void changePassword() {
		// Set value to send to newPassword method.
		String tempString = new String();
		if (dbPassword.length() > 0 && dbPassword != null 
				&& !dbPassword.equals(initPW)) {
			tempString = dbPassword;
		}
		// Allow user to enter new password.
		newPassword(tempString);
	}

	/**
	 * Setter method to set a new password.
	 * 
	 * @param newPW the new Password.
	 */
	public final void setPassword(final String newPW) {
		if (newPW.length() > 0 && newPW != null && !newPW.equals(initPW)) {
			dbPassword = newPW;
		}
	}

	/**
	 * Open a dialog to allow user to enter or change password.
	 * 
	 * @param initVal -
	 *            The current password.
	 */
	private void newPassword(String initVal) {
		// Create validator for password input to be used by dialog.
		PasswordDialog pwDialog = new PasswordDialog(PlatformUI.getWorkbench()
				.getActiveWorkbenchWindow().getShell(), initVal);
		pwDialog.create();
		if (initVal.length() == 0 || initVal == null) {
			pwDialog.getButton(IDialogConstants.OK_ID).setEnabled(false);
		} else {
			pwDialog.getButton(IDialogConstants.OK_ID).setEnabled(true);
			
		}
		pwDialog.open();
	}

	/*
	 * Getter method to provide the current password.
	 */
	public final String getPassword() {
		return dbPassword;
	}

}
